==> dnet-collector-plugins-1.3.23-20181108.163109-5-sources.jar: eu/dnetlib/data/collector/plugins/schemaorg/SchemaOrgMainReactome.java <==
package eu.dnetlib.data.collector.plugins.schemaorg;

import eu.dnetlib.data.collector.plugins.schemaorg.sitemapindex.SitemapFileIterator;
import eu.dnetlib.data.collector.rmi.InterfaceDescriptor;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;
import org.dom4j.Document;
import org.dom4j.io.SAXReader;

import java.io.File;
import java.io.FileWriter;
import java.io.StringReader;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

public class SchemaOrgMainReactome {

    private static final Log log = LogFactory.getLog(SchemaOrgMainReactome.class);

    public static void main(String[] args) throws Exception {

        ConsoleAppender console = new ConsoleAppender();
        console.setLayout(new PatternLayout("%d [%p|%c|%C{1}] %m%n"));
        console.setThreshold(Level.DEBUG);
        console.activateOptions();
        Logger.getLogger("eu.dnetlib.data.collector.plugins").addAppender(console);

        HashMap<String,String> params = new HashMap<>();
        params.put("consumerBlockPolling", Boolean.toString(true));
        params.put("consumerBlockPollingTimeout", "2");
        params.put("consumerBlockPollingTimeoutUnit", TimeUnit.MINUTES.toString());
        params.put("endpointCharset", StandardCharsets.UTF_8.name());
        params.put("updatedDateFormat", "YYYY-MM-DD");
        params.put("createdDateFormat", "YYYY-MM-DD");
        params.put("publicationDateFormat", "YYYY-MM-DD");
        params.put("contributorFallbackType", DatasetDocument.Contributor.ContributorType.Other.toString());
        params.put("identifierFallbackType", DatasetDocument.Identifier.IdentifierType.Handle.toString());
        params.put("identifierFallbackURL", Boolean.toString(true));
        params.put("identifierMappingARK", "ark, ARK");
        params.put("identifierMappingDOI", "doi, DOI");
        params.put("identifierMappingHandle", "Handle, HANDLE");
        params.put("identifierMappingPURL", "purl, PURL");
        params.put("identifierMappingURN", "urn, URN");
        params.put("identifierMappingURL", "url, URL");

        params.put("repositoryAccessType", "sitemapindex");
        params.put("sitemap_queueSize", "100");
        params.put("sitemap_IndexCharset", StandardCharsets.UTF_8.name());
        params.put("sitemap_FileCharset", StandardCharsets.UTF_8.name());
        params.put("sitemap_FileSchema", SitemapFileIterator.Options.SitemapSchemaType.Text.toString());
        params.put("sitemap_FileType", SitemapFileIterator.Options.SitemapFileType.GZ.toString());



        InterfaceDescriptor descriptor = new InterfaceDescriptor();
        descriptor.setId("schema.org - reactome");
        descriptor.setBaseUrl("https://reactome.org/sitemapindex.xml");

        descriptor.setParams(params);

        SchemaOrgPlugin schemaOrgPlugin = new SchemaOrgPlugin();

        Iterable<String> iterable = schemaOrgPlugin.collect(descriptor, null, null);

        String outDir = params.get("repositoryAccessType");

        log.info("saving content in " + outDir);

        File directory = new File(outDir);
        if (directory.exists()) {
            log.info(directory.getAbsolutePath() + " exists, cleaning up");
            FileUtils.deleteDirectory(directory);
        }
        FileUtils.forceMkdir(directory);

        int skipped = 0;
        for(String item : iterable) {

            final Document doc = new SAXReader().read(new StringReader(item));

            String id = doc.valueOf("/*[local-name() = 'dataset']/*[local-name() = 'identifier']/text()");
            if (StringUtils.isNotBlank(id)) {
                log.info(item);
                String fileName = outDir + "/" + id;
                FileWriter w = new FileWriter(fileName);
                w.write(item);
                w.close();
                log.info("wrote " + fileName);
            } else {
                skipped++;
            }
            if (skipped % 100 == 0) {
                log.info("skipped so far " + skipped);
            }
        }

        log.info("Done! skipped " + skipped);
    }

}

==> dnet-collector-plugins-1.3.23-20181109.104854-6-sources.jar: eu/dnetlib/data/collector/plugins/schemaorg/SchemaOrgMainReactome.java <==
package eu.dnetlib.data.collector.plugins.schemaorg;

import eu.dnetlib.data.collector.plugins.schemaorg.sitemapindex.SitemapFileIterator;
import eu.dnetlib.data.collector.rmi.InterfaceDescriptor;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;
import org.dom4j.Document;
import org.dom4j.io.SAXReader;

import java.io.File;
import java.io.FileWriter;
import java.io.StringReader;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

public class SchemaOrgMainReactome {

    private static final Log log = LogFactory.getLog(SchemaOrgMainReactome.class);

    public static void main(String[] args) throws Exception {

        ConsoleAppender console = new ConsoleAppender();
        console.setLayout(new PatternLayout("%d [%p|%c|%C{1}] %m%n"));
        console.setThreshold(Level.DEBUG);
        console.activateOptions();
        Logger.getLogger("eu.dnetlib.data.collector.plugins").addAppender(console);

        HashMap<String,String> params = new HashMap<>();
        params.put("consumerBlockPolling", Boolean.toString(true));
        params.put("consumerBlockPollingTimeout", "2");
        params.put("consumerBlockPollingTimeoutUnit", TimeUnit.MINUTES.toString());
        params.put("endpointCharset", StandardCharsets.UTF_8.name());
        params.put("updatedDateFormat", "YYYY-MM-DD");
        params.put("createdDateFormat", "YYYY-MM-DD");
        params.put("publicationDateFormat", "YYYY-MM-DD");
        params.put("contributorFallbackType", DatasetDocument.Contributor.ContributorType.Other.toString());
        params.put("identifierFallbackType", DatasetDocument.Identifier.IdentifierType.Handle.toString());
        params.put("identifierFallbackURL", Boolean.toString(true));
        params.put("identifierMappingARK", "ark, ARK");
        params.put("identifierMappingDOI", "doi, DOI");
        params.put("identifierMappingHandle", "Handle, HANDLE");
        params.put("identifierMappingPURL", "purl, PURL");
        params.put("identifierMappingURN", "urn, URN");
        params.put("identifierMappingURL", "url, URL");

        params.put("repositoryAccessType", "sitemapindex");
        params.put("sitemap_queueSize", "100");
        params.put("sitemap_IndexCharset", StandardCharsets.UTF_8.name());
        params.put("sitemap_FileCharset", StandardCharsets.UTF_8.name());
        params.put("sitemap_FileSchema", SitemapFileIterator.Options.SitemapSchemaType.Text.toString());
        params.put("sitemap_FileType", SitemapFileIterator.Options.SitemapFileType.GZ.toString());



        InterfaceDescriptor descriptor = new InterfaceDescriptor();
        descriptor.setId("schema.org - reactome");
        descriptor.setBaseUrl("https://reactome.org/sitemapindex.xml");

        descriptor.setParams(params);

        SchemaOrgPlugin schemaOrgPlugin = new SchemaOrgPlugin();

        Iterable<String> iterable = schemaOrgPlugin.collect(descriptor, null, null);

        String outDir = params.get("repositoryAccessType");

        log.info("saving content in " + outDir);

        File directory = new File(outDir);
        if (directory.exists()) {
            log.info(directory.getAbsolutePath() + " exists, cleaning up");
            FileUtils.deleteDirectory(directory);
        }
        FileUtils.forceMkdir(directory);
        Utils.writeFiles(iterable, outDir);
    }

}
